@@ -8,8 +8,6 @@ from object_permissions.registration import TestModel, TestModelChild, \
     TestModelChildChild, UnknownPermissionException
 from object_permissions.signals import view_edit_user
 
-from object_permissions.templatetags.object_permission_tags import \
-                number_group_admins
 
 __all__ = ('TestGroups','TestGroupViews')
 
@@ -72,7 +70,7 @@ class TestGroups(TestCase):
     
     def test_permissions(self):
         """ Verify all model perms are created """
-        self.assert_('admin' in get_model_perms(Group))
+        self.assertTrue('admin' in get_model_perms(Group))
     
     def test_grant_group_permissions(self):
         """
@@ -89,51 +87,51 @@ class TestGroups(TestCase):
         
         # grant single property
         group0.grant('Perm1', object0)
-        self.assert_(user0.has_perm('Perm1', object0))
+        self.assertTrue(user0.has_perm('Perm1', object0))
         self.assertFalse(user0.has_perm('Perm1', object1))
         self.assertFalse(user1.has_perm('Perm1', object0))
         self.assertFalse(user1.has_perm('Perm1', object1))
         
         # grant property again
         group0.grant('Perm1', object0)
-        self.assert_(user0.has_perm('Perm1', object0))
+        self.assertTrue(user0.has_perm('Perm1', object0))
         self.assertFalse(user0.has_perm('Perm1', object1))
         self.assertFalse(user1.has_perm('Perm1', object0))
         self.assertFalse(user1.has_perm('Perm1', object1))
         
         # grant second property
         group0.grant('Perm2', object0)
-        self.assert_(user0.has_perm('Perm1', object0))
+        self.assertTrue(user0.has_perm('Perm1', object0))
         self.assertFalse(user0.has_perm('Perm1', object1))
         self.assertFalse(user1.has_perm('Perm1', object0))
         self.assertFalse(user1.has_perm('Perm1', object1))
-        self.assert_(user0.has_perm('Perm2', object0))
+        self.assertTrue(user0.has_perm('Perm2', object0))
         self.assertFalse(user0.has_perm('Perm2', object1))
         self.assertFalse(user1.has_perm('Perm2', object0))
         self.assertFalse(user1.has_perm('Perm2', object1))
         
         # grant property to another object
         group0.grant('Perm2', object1)
-        self.assert_(user0.has_perm('Perm1', object0))
+        self.assertTrue(user0.has_perm('Perm1', object0))
         self.assertFalse(user0.has_perm('Perm1', object1))
         self.assertFalse(user1.has_perm('Perm1', object0))
         self.assertFalse(user1.has_perm('Perm1', object1))
-        self.assert_(user0.has_perm('Perm2', object0))
-        self.assert_(user0.has_perm('Perm2', object1))
+        self.assertTrue(user0.has_perm('Perm2', object0))
+        self.assertTrue(user0.has_perm('Perm2', object1))
         self.assertFalse(user1.has_perm('Perm2', object0))
         self.assertFalse(user1.has_perm('Perm2', object1))
         
         # grant perms to other user
         group1.grant('Perm3', object0)
-        self.assert_(user0.has_perm('Perm1', object0))
+        self.assertTrue(user0.has_perm('Perm1', object0))
         self.assertFalse(user0.has_perm('Perm1', object1))
         self.assertFalse(user1.has_perm('Perm1', object0))
         self.assertFalse(user1.has_perm('Perm1', object1))
-        self.assert_(user0.has_perm('Perm2', object0))
-        self.assert_(user0.has_perm('Perm2', object1))
+        self.assertTrue(user0.has_perm('Perm2', object0))
+        self.assertTrue(user0.has_perm('Perm2', object1))
         self.assertFalse(user1.has_perm('Perm2', object0))
         self.assertFalse(user1.has_perm('Perm2', object1))
-        self.assert_(user1.has_perm('Perm3', object0))
+        self.assertTrue(user1.has_perm('Perm3', object0))
         
         def grant_unknown():
             group1.grant('UnknownPerm', object0)
@@ -401,11 +399,11 @@ class TestGroups(TestCase):
         group0.grant('Perm3', object1)
         group1.grant('Perm2', object1)
         
-        self.assert_(group0 in get_groups(object0))
+        self.assertTrue(group0 in get_groups(object0))
         self.assertFalse(group1 in get_groups(object0))
-        self.assert_(group0 in get_groups(object1))
-        self.assert_(group1 in get_groups(object1))
-        self.assert_(len(get_groups(object1))==2)
+        self.assertTrue(group0 in get_groups(object1))
+        self.assertTrue(group1 in get_groups(object1))
+        self.assertTrue(len(get_groups(object1))==2)
     
     def test_get_groups_any(self):
         """
@@ -422,26 +420,26 @@ class TestGroups(TestCase):
         self.assertFalse(user1 in get_groups_any(object0, ['Perm1']))
         
         # explicit any perms
-        self.assert_(group0 in get_groups_any(object0))
-        self.assert_(group0 in get_groups_any(object1))
+        self.assertTrue(group0 in get_groups_any(object0))
+        self.assertTrue(group0 in get_groups_any(object1))
         self.assertFalse(group1 in get_groups_any(object0))
-        self.assert_(group1 in get_groups_any(object1))
+        self.assertTrue(group1 in get_groups_any(object1))
         
         # has perms, but not the right one
         self.assertFalse(group0 in get_groups_any(object0, ['Perm3']))
         
         # has one perm, but not all
-        self.assert_(group0 in get_groups_any(object0, ['Perm1','Perm3']))
-        self.assert_(group0 in get_groups_any(object1, ['Perm1','Perm2']))
+        self.assertTrue(group0 in get_groups_any(object0, ['Perm1','Perm3']))
+        self.assertTrue(group0 in get_groups_any(object1, ['Perm1','Perm2']))
         
         # has single perm
-        self.assert_(group0 in get_groups_any(object0, ['Perm1']))
-        self.assert_(group0 in get_groups_any(object0, ['Perm2']))
-        self.assert_(group1 in get_groups_any(object1, ['Perm2']))
+        self.assertTrue(group0 in get_groups_any(object0, ['Perm1']))
+        self.assertTrue(group0 in get_groups_any(object0, ['Perm2']))
+        self.assertTrue(group1 in get_groups_any(object1, ['Perm2']))
         
         # has multiple perms
-        self.assert_(group0 in get_groups_any(object0, ['Perm1','Perm2']))
-        self.assert_(group0 in get_groups_any(object1, ['Perm1','Perm3']))    
+        self.assertTrue(group0 in get_groups_any(object0, ['Perm1','Perm2']))
+        self.assertTrue(group0 in get_groups_any(object1, ['Perm1','Perm3']))
     
     def test_get_groups_all(self):
         """
@@ -465,13 +463,13 @@ class TestGroups(TestCase):
         self.assertFalse(group0 in get_groups_all(object1, ['Perm1','Perm2']))
         
         # has single perm
-        self.assert_(group0 in get_groups_all(object0, ['Perm1']))
-        self.assert_(group0 in get_groups_all(object0, ['Perm2']))
-        self.assert_(group1 in get_groups_all(object1, ['Perm2']))
+        self.assertTrue(group0 in get_groups_all(object0, ['Perm1']))
+        self.assertTrue(group0 in get_groups_all(object0, ['Perm2']))
+        self.assertTrue(group1 in get_groups_all(object1, ['Perm2']))
         
         # has multiple perms
-        self.assert_(group0 in get_groups_all(object0, ['Perm1','Perm2']))
-        self.assert_(group0 in get_groups_all(object1, ['Perm1','Perm3']))
+        self.assertTrue(group0 in get_groups_all(object0, ['Perm1','Perm2']))
+        self.assertTrue(group0 in get_groups_all(object1, ['Perm1','Perm3']))
 
     def test_user_get_perms(self):
         """
@@ -547,25 +545,25 @@ class TestGroups(TestCase):
         user0.grant('Perm4', object4)
         
         # retrieve single perm
-        self.assert_(object0 in user0.get_objects_any_perms(TestModel, ['Perm1']))
-        self.assert_(object1 in user0.get_objects_any_perms(TestModel, ['Perm2']))
-        self.assert_(object2 in user1.get_objects_any_perms(TestModel, ['Perm3']))
-        self.assert_(object3 in user1.get_objects_any_perms(TestModel, ['Perm4']))
+        self.assertTrue(object0 in user0.get_objects_any_perms(TestModel, ['Perm1']))
+        self.assertTrue(object1 in user0.get_objects_any_perms(TestModel, ['Perm2']))
+        self.assertTrue(object2 in user1.get_objects_any_perms(TestModel, ['Perm3']))
+        self.assertTrue(object3 in user1.get_objects_any_perms(TestModel, ['Perm4']))
         
         # retrieve multiple perms
         query = user0.get_objects_any_perms(TestModel, ['Perm1', 'Perm2', 'Perm3'])
-        self.assert_(object0 in query)
-        self.assert_(object1 in query)
+        self.assertTrue(object0 in query)
+        self.assertTrue(object1 in query)
         self.assertEqual(2, query.count())
         query = user1.get_objects_any_perms(TestModel, ['Perm1', 'Perm3', 'Perm4'])
-        self.assert_(object2 in query)
-        self.assert_(object3 in query)
+        self.assertTrue(object2 in query)
+        self.assertTrue(object3 in query)
         self.assertEqual(2, query.count())
         
         # mix of group and users
         query = user0.get_objects_any_perms(TestModel, ['Perm1', 'Perm4'])
-        self.assert_(object0 in query)
-        self.assert_(object4 in query)
+        self.assertTrue(object0 in query)
+        self.assertTrue(object4 in query)
         self.assertEqual(2, query.count())
         
         # retrieve no results
@@ -576,12 +574,12 @@ class TestGroups(TestCase):
         
         # extra kwargs
         query = user0.get_objects_any_perms(TestModel, ['Perm1', 'Perm2', 'Perm3']).filter(name='test0')
-        self.assert_(object0 in query)
+        self.assertTrue(object0 in query)
         self.assertEqual(1, query.count())
         
         # exclude groups
         query = user0.get_objects_any_perms(TestModel, ['Perm1', 'Perm4'], groups=False)
-        self.assert_(object4 in query)
+        self.assertTrue(object4 in query)
         self.assertEqual(1, query.count())
     
     def test_user_get_objects_any_perms_related(self):
@@ -616,45 +614,45 @@ class TestGroups(TestCase):
         
         # related field with implicit perms
         query = user0.get_objects_any_perms(TestModelChild, parent=None)
-        self.assert_(child0 in query, 'user should have perms on parent and directly')
-        self.assert_(child1 in query, 'user should have perms on parent')
-        self.assert_(child2 in query, 'user should have perms on parent, and directly')
+        self.assertTrue(child0 in query, 'user should have perms on parent and directly')
+        self.assertTrue(child1 in query, 'user should have perms on parent')
+        self.assertTrue(child2 in query, 'user should have perms on parent, and directly')
         self.assertFalse(child3 in query, 'user should have no perms on this object or its parent')
         self.assertEqual(3, len(query))
         
         # related field with single perms
         query = user0.get_objects_any_perms(TestModelChild, parent=['Perm3'])
         
-        self.assert_(child0 in query, 'user should have perms on parent and directly')
-        self.assert_(child1 in query, 'user should have perms on parent')
-        self.assert_(child2 in query, 'user should have perms on parent')
+        self.assertTrue(child0 in query, 'user should have perms on parent and directly')
+        self.assertTrue(child1 in query, 'user should have perms on parent')
+        self.assertTrue(child2 in query, 'user should have perms on parent')
         self.assertFalse(child3 in query, 'user should have no perms on this object or its parent')
         self.assertEqual(3, len(query), query.values('id'))
         
         # related field with multiple perms
         query = user0.get_objects_any_perms(TestModelChild, parent=['Perm1','Perm3'])
-        self.assert_(child0 in query, 'user should have perms on parent and directly')
-        self.assert_(child1 in query, 'user should have perms on parent')
-        self.assert_(child2 in query, 'user should have perms on parent')
+        self.assertTrue(child0 in query, 'user should have perms on parent and directly')
+        self.assertTrue(child1 in query, 'user should have perms on parent')
+        self.assertTrue(child2 in query, 'user should have perms on parent')
         self.assertFalse(child3 in query, 'user should have no perms on this object or its parent')
         self.assertEqual(3, len(query))
         
         # mix of direct and related perms
         query = user0.get_objects_any_perms(TestModelChild, perms=['Perm4'], parent=['Perm1'])
         self.assertEqual(2, len(query))
-        self.assert_(child0 in query, 'user should have perms on parent and directly')
+        self.assertTrue(child0 in query, 'user should have perms on parent and directly')
         self.assertFalse(child1 in query, 'user should not have perms on parent')
-        self.assert_(child2 in query, 'user should have perms directly')
+        self.assertTrue(child2 in query, 'user should have perms directly')
         self.assertFalse(child3 in query, 'user should have no perms on this object or its parent')
         
         # multiple relations
         query = user0.get_objects_any_perms(TestModelChildChild, parent=['Perm2'], parent__parent=['Perm1'])
-        self.assert_(childchild in query)
+        self.assertTrue(childchild in query)
         self.assertEqual(1, len(query))
         
         # exclude groups
         query = user0.get_objects_any_perms(TestModelChild, groups=False, parent=['Perm1'])
-        self.assert_(child0 in query)
+        self.assertTrue(child0 in query)
         self.assertEqual(1, len(query))
     
     def test_user_has_any_perms_on_model(self):
@@ -677,22 +675,22 @@ class TestGroups(TestCase):
         user0.grant('Perm4', object4)
         
         # check single perm
-        self.assert_(user0.has_any_perms(TestModel, ['Perm1']))
-        self.assert_(user0.has_any_perms(TestModel, ['Perm2']))
-        self.assert_(user1.has_any_perms(TestModel, ['Perm3']))
+        self.assertTrue(user0.has_any_perms(TestModel, ['Perm1']))
+        self.assertTrue(user0.has_any_perms(TestModel, ['Perm2']))
+        self.assertTrue(user1.has_any_perms(TestModel, ['Perm3']))
         
         # check multiple perms
-        self.assert_(user0.has_any_perms(TestModel, ['Perm1', 'Perm4']))
-        self.assert_(user0.has_any_perms(TestModel, ['Perm1', 'Perm2']))
-        self.assert_(user1.has_any_perms(TestModel, ['Perm3', 'Perm4']))
+        self.assertTrue(user0.has_any_perms(TestModel, ['Perm1', 'Perm4']))
+        self.assertTrue(user0.has_any_perms(TestModel, ['Perm1', 'Perm2']))
+        self.assertTrue(user1.has_any_perms(TestModel, ['Perm3', 'Perm4']))
         
         # no results
         self.assertFalse(user0.has_any_perms(TestModel, ['Perm3']))
         self.assertFalse(user1.has_any_perms(TestModel, ['Perm4']))
         
         # excluding group perms
-        self.assert_(user0.has_any_perms(TestModel, ['Perm4'], False))
-        self.assert_(user0.has_any_perms(TestModel, ['Perm2', 'Perm4'], False))
+        self.assertTrue(user0.has_any_perms(TestModel, ['Perm4'], False))
+        self.assertTrue(user0.has_any_perms(TestModel, ['Perm2', 'Perm4'], False))
         self.assertFalse(user0.has_any_perms(TestModel, ['Perm2'], False))
     
     def test_user_has_all_perms_on_model(self):
@@ -716,21 +714,21 @@ class TestGroups(TestCase):
         user0.grant('Perm4', object4)
         
         # check single perm
-        self.assert_(user0.has_all_perms(TestModel, ['Perm1']))
-        self.assert_(user0.has_all_perms(TestModel, ['Perm2']))
-        self.assert_(user1.has_all_perms(TestModel, ['Perm3']))
+        self.assertTrue(user0.has_all_perms(TestModel, ['Perm1']))
+        self.assertTrue(user0.has_all_perms(TestModel, ['Perm2']))
+        self.assertTrue(user1.has_all_perms(TestModel, ['Perm3']))
         
         # check multiple perms
         self.assertFalse(user0.has_all_perms(TestModel, ['Perm1', 'Perm4']))
         self.assertFalse(user0.has_all_perms(TestModel, ['Perm1', 'Perm2']))
-        self.assert_(user0.has_all_perms(TestModel, ['Perm1', 'Perm3']))
+        self.assertTrue(user0.has_all_perms(TestModel, ['Perm1', 'Perm3']))
         self.assertFalse(user1.has_all_perms(TestModel, ['Perm3', 'Perm4']))
         
         # no results
         self.assertFalse(user1.has_all_perms(TestModel, ['Perm4']))
         
         # excluding group perms
-        self.assert_(user0.has_all_perms(TestModel, ['Perm4'], False))
+        self.assertTrue(user0.has_all_perms(TestModel, ['Perm4'], False))
         self.assertFalse(user0.has_all_perms(TestModel, ['Perm2', 'Perm4'], False))
         self.assertFalse(user0.has_all_perms(TestModel, ['Perm2'], False))
     
@@ -766,8 +764,8 @@ class TestGroups(TestCase):
         # related field with single perms
         query = user0.get_objects_all_perms(TestModelChild, perms=['Perm1'], parent=['Perm1'])
         self.assertEqual(2, len(query))
-        self.assert_(child0 in query)
-        self.assert_(child1 in query)
+        self.assertTrue(child0 in query)
+        self.assertTrue(child1 in query)
         self.assertFalse(child2 in query)
         
         # related field with single perms - has parent but not child
@@ -782,17 +780,17 @@ class TestGroups(TestCase):
         query = user0.get_objects_all_perms(TestModelChild, perms=['Perm1'], parent=['Perm1','Perm2'])
         self.assertEqual(1, len(query))
         self.assertFalse(child0 in query)
-        self.assert_(child1 in query)
+        self.assertTrue(child1 in query)
         self.assertFalse(child2 in query)
         
         # multiple relations
         query = user0.get_objects_all_perms(TestModelChildChild, perms=['Perm1'], parent=['Perm1'], parent__parent=['Perm1'])
         self.assertEqual(1, len(query))
-        self.assert_(childchild in query)
+        self.assertTrue(childchild in query)
         
         # exclude groups
         query = user0.get_objects_all_perms(TestModelChild, perms=['Perm1'], groups=False, parent=['Perm1'])
-        self.assert_(child0 in query)
+        self.assertTrue(child0 in query)
         self.assertEqual(1, len(query))
     def test_get_perms(self):
         """
@@ -835,14 +833,14 @@ class TestGroups(TestCase):
         group0.grant('Perm4', object4)
         
         # check single perm
-        self.assert_(group0.has_any_perms(TestModel, ['Perm1']))
-        self.assert_(group0.has_any_perms(TestModel, ['Perm2']))
-        self.assert_(group1.has_any_perms(TestModel, ['Perm3']))
+        self.assertTrue(group0.has_any_perms(TestModel, ['Perm1']))
+        self.assertTrue(group0.has_any_perms(TestModel, ['Perm2']))
+        self.assertTrue(group1.has_any_perms(TestModel, ['Perm3']))
         
         # check multiple perms
-        self.assert_(group0.has_any_perms(TestModel, ['Perm1', 'Perm4']))
-        self.assert_(group0.has_any_perms(TestModel, ['Perm1', 'Perm2']))
-        self.assert_(group1.has_any_perms(TestModel, ['Perm3', 'Perm4']))
+        self.assertTrue(group0.has_any_perms(TestModel, ['Perm1', 'Perm4']))
+        self.assertTrue(group0.has_any_perms(TestModel, ['Perm1', 'Perm2']))
+        self.assertTrue(group1.has_any_perms(TestModel, ['Perm3', 'Perm4']))
         
         # no results
         self.assertFalse(group0.has_any_perms(TestModel, ['Perm3']))
@@ -868,14 +866,14 @@ class TestGroups(TestCase):
         group1.grant('Perm3', object2)
         
         # check single perm
-        self.assert_(group0.has_all_perms(TestModel, ['Perm1']))
-        self.assert_(group0.has_all_perms(TestModel, ['Perm2']))
-        self.assert_(group1.has_all_perms(TestModel, ['Perm3']))
+        self.assertTrue(group0.has_all_perms(TestModel, ['Perm1']))
+        self.assertTrue(group0.has_all_perms(TestModel, ['Perm2']))
+        self.assertTrue(group1.has_all_perms(TestModel, ['Perm3']))
         
         # check multiple perms
         self.assertFalse(group0.has_all_perms(TestModel, ['Perm1', 'Perm4']))
         self.assertFalse(group0.has_all_perms(TestModel, ['Perm1', 'Perm2']))
-        self.assert_(group0.has_all_perms(TestModel, ['Perm1', 'Perm3']))
+        self.assertTrue(group0.has_all_perms(TestModel, ['Perm1', 'Perm3']))
         self.assertFalse(group1.has_all_perms(TestModel, ['Perm3', 'Perm4']))
         
         # no results
@@ -901,26 +899,26 @@ class TestGroups(TestCase):
         group1.grant('Perm4', object3)
         
         # implicit any
-        self.assert_(object0 in group0.get_objects_any_perms(TestModel, ['Perm1']))
-        self.assert_(object1 in group0.get_objects_any_perms(TestModel, ['Perm2']))
+        self.assertTrue(object0 in group0.get_objects_any_perms(TestModel, ['Perm1']))
+        self.assertTrue(object1 in group0.get_objects_any_perms(TestModel, ['Perm2']))
         self.assertFalse(object2 in group0.get_objects_any_perms(TestModel, ['Perm2']))
-        self.assert_(object2 in group1.get_objects_any_perms(TestModel, ['Perm3']))
-        self.assert_(object3 in group1.get_objects_any_perms(TestModel, ['Perm4']))
+        self.assertTrue(object2 in group1.get_objects_any_perms(TestModel, ['Perm3']))
+        self.assertTrue(object3 in group1.get_objects_any_perms(TestModel, ['Perm4']))
         
         # retrieve single perm
-        self.assert_(object0 in group0.get_objects_any_perms(TestModel, ['Perm1']))
-        self.assert_(object1 in group0.get_objects_any_perms(TestModel, ['Perm2']))
-        self.assert_(object2 in group1.get_objects_any_perms(TestModel, ['Perm3']))
-        self.assert_(object3 in group1.get_objects_any_perms(TestModel, ['Perm4']))
+        self.assertTrue(object0 in group0.get_objects_any_perms(TestModel, ['Perm1']))
+        self.assertTrue(object1 in group0.get_objects_any_perms(TestModel, ['Perm2']))
+        self.assertTrue(object2 in group1.get_objects_any_perms(TestModel, ['Perm3']))
+        self.assertTrue(object3 in group1.get_objects_any_perms(TestModel, ['Perm4']))
         
         # retrieve multiple perms
         query = group0.get_objects_any_perms(TestModel, ['Perm1', 'Perm2', 'Perm3'])
-        self.assert_(object0 in query)
-        self.assert_(object1 in query)
+        self.assertTrue(object0 in query)
+        self.assertTrue(object1 in query)
         self.assertEqual(2, query.count())
         query = group1.get_objects_any_perms(TestModel, ['Perm1', 'Perm3', 'Perm4'])
-        self.assert_(object2 in query)
-        self.assert_(object3 in query)
+        self.assertTrue(object2 in query)
+        self.assertTrue(object3 in query)
         self.assertEqual(2, query.count())
         
         # retrieve no results
@@ -931,7 +929,7 @@ class TestGroups(TestCase):
         
         # extra kwargs
         query = group0.get_objects_any_perms(TestModel, ['Perm1', 'Perm2', 'Perm3']).filter( name='test0')
-        self.assert_(object0 in query)
+        self.assertTrue(object0 in query)
         self.assertEqual(1, query.count())
     
     def test_group_get_objects_any_perms_related(self):
@@ -963,40 +961,40 @@ class TestGroups(TestCase):
         
         # related field with implicit perms
         query = group0.get_objects_any_perms(TestModelChild, parent=None)
-        self.assert_(child0 in query, 'user should have perms on parent and directly')
-        self.assert_(child1 in query, 'user should have perms on parent')
-        self.assert_(child2 in query, 'user should have perms on parent, and directly')
+        self.assertTrue(child0 in query, 'user should have perms on parent and directly')
+        self.assertTrue(child1 in query, 'user should have perms on parent')
+        self.assertTrue(child2 in query, 'user should have perms on parent, and directly')
         self.assertFalse(child3 in query, 'user should have no perms on this object or its parent')
         self.assertEqual(3, len(query))
         
         # related field with single perms
         query = group0.get_objects_any_perms(TestModelChild, parent=['Perm3'])
         
-        self.assert_(child0 in query, 'user should have perms on parent and directly')
-        self.assert_(child1 in query, 'user should have perms on parent')
-        self.assert_(child2 in query, 'user should have perms on parent')
+        self.assertTrue(child0 in query, 'user should have perms on parent and directly')
+        self.assertTrue(child1 in query, 'user should have perms on parent')
+        self.assertTrue(child2 in query, 'user should have perms on parent')
         self.assertFalse(child3 in query, 'user should have no perms on this object or its parent')
         self.assertEqual(3, len(query), query.values('id'))
         
         # related field with multiple perms
         query = group0.get_objects_any_perms(TestModelChild, parent=['Perm1','Perm3'])
-        self.assert_(child0 in query, 'user should have perms on parent and directly')
-        self.assert_(child1 in query, 'user should have perms on parent')
-        self.assert_(child2 in query, 'user should have perms on parent')
+        self.assertTrue(child0 in query, 'user should have perms on parent and directly')
+        self.assertTrue(child1 in query, 'user should have perms on parent')
+        self.assertTrue(child2 in query, 'user should have perms on parent')
         self.assertFalse(child3 in query, 'user should have no perms on this object or its parent')
         self.assertEqual(3, len(query))
         
         # mix of direct and related perms
         query = group0.get_objects_any_perms(TestModelChild, perms=['Perm4'], parent=['Perm1'])
         self.assertEqual(2, len(query))
-        self.assert_(child0 in query, 'user should have perms on parent and directly')
+        self.assertTrue(child0 in query, 'user should have perms on parent and directly')
         self.assertFalse(child1 in query, 'user should not have perms on parent')
-        self.assert_(child2 in query, 'user should have perms directly')
+        self.assertTrue(child2 in query, 'user should have perms directly')
         self.assertFalse(child3 in query, 'user should have no perms on this object or its parent')
         
         # multiple relations
         query = group0.get_objects_any_perms(TestModelChildChild, parent=['Perm2'], parent__parent=['Perm1'])
-        self.assert_(childchild in query)
+        self.assertTrue(childchild in query)
         self.assertEqual(1, len(query))
     
     def test_group_get_objects_all_perms(self):
@@ -1020,18 +1018,18 @@ class TestGroups(TestCase):
         group1.grant('Perm4', object2)
         
         # retrieve single perm
-        self.assert_(object0 in group0.get_objects_all_perms(TestModel, ['Perm1']))
-        self.assert_(object1 in group0.get_objects_all_perms(TestModel, ['Perm4']))
-        self.assert_(object2 in group1.get_objects_all_perms(TestModel, ['Perm3']))
-        self.assert_(object2 in group1.get_objects_all_perms(TestModel, ['Perm4']))
+        self.assertTrue(object0 in group0.get_objects_all_perms(TestModel, ['Perm1']))
+        self.assertTrue(object1 in group0.get_objects_all_perms(TestModel, ['Perm4']))
+        self.assertTrue(object2 in group1.get_objects_all_perms(TestModel, ['Perm3']))
+        self.assertTrue(object2 in group1.get_objects_all_perms(TestModel, ['Perm4']))
         
         # retrieve multiple perms
         query = group0.get_objects_all_perms(TestModel, ['Perm1', 'Perm2'])
-        self.assert_(object0 in query)
+        self.assertTrue(object0 in query)
         self.assertFalse(object1 in query)
         self.assertEqual(1, query.count())
         query = group1.get_objects_all_perms(TestModel, ['Perm3', 'Perm4'])
-        self.assert_(object2 in query)
+        self.assertTrue(object2 in query)
         self.assertFalse(object3 in query)
         self.assertEqual(1, query.count())
         
@@ -1042,7 +1040,7 @@ class TestGroups(TestCase):
         
         # extra kwargs
         query = group0.get_objects_all_perms(TestModel, ['Perm1', 'Perm2']).filter( name='test0')
-        self.assert_(object0 in query)
+        self.assertTrue(object0 in query)
         self.assertEqual(1, query.count())
     
     def test_group_get_objects_all_perms_related(self):
@@ -1074,8 +1072,8 @@ class TestGroups(TestCase):
         # related field with single perms
         query = group0.get_objects_all_perms(TestModelChild, perms=['Perm1'], parent=['Perm1'])
         self.assertEqual(2, len(query))
-        self.assert_(child0 in query)
-        self.assert_(child1 in query)
+        self.assertTrue(child0 in query)
+        self.assertTrue(child1 in query)
         self.assertFalse(child2 in query)
         
         # related field with single perms - has parent but not child
@@ -1090,13 +1088,13 @@ class TestGroups(TestCase):
         query = group0.get_objects_all_perms(TestModelChild, perms=['Perm1'], parent=['Perm1','Perm2'])
         self.assertEqual(1, len(query))
         self.assertFalse(child0 in query)
-        self.assert_(child1 in query)
+        self.assertTrue(child1 in query)
         self.assertFalse(child2 in query)
         
         # multiple relations
         query = group0.get_objects_all_perms(TestModelChildChild, perms=['Perm1'], parent=['Perm1'], parent__parent=['Perm1'])
         self.assertEqual(1, len(query))
-        self.assert_(childchild in query)
+        self.assertTrue(childchild in query)
     
     def test_group_get_all_objects_any_perms(self):
         group0 = self.test_save('TestGroup0', user0)
@@ -1114,18 +1112,18 @@ class TestGroups(TestCase):
         group0.grant('Perm4', object1)
         
         perm_dict = group0.get_all_objects_any_perms()
-        self.assert_(isinstance(perm_dict, (dict,)))
-        self.assert_(TestModel in perm_dict, perm_dict.keys())
-        self.assert_(object0 in perm_dict[TestModel])
-        self.assert_(object1 in perm_dict[TestModel])
+        self.assertTrue(isinstance(perm_dict, (dict,)))
+        self.assertTrue(TestModel in perm_dict, perm_dict.keys())
+        self.assertTrue(object0 in perm_dict[TestModel])
+        self.assertTrue(object1 in perm_dict[TestModel])
         self.assertFalse(object2 in perm_dict[TestModel])
         self.assertFalse(object3 in perm_dict[TestModel])
         self.assertFalse(object4 in perm_dict[TestModel])
         
         # no perms
         perm_dict = group1.get_all_objects_any_perms()
-        self.assert_(isinstance(perm_dict, (dict,)))
-        self.assert_(TestModel in perm_dict, perm_dict.keys())
+        self.assertTrue(isinstance(perm_dict, (dict,)))
+        self.assertTrue(TestModel in perm_dict, perm_dict.keys())
         self.assertEqual(0, perm_dict[TestModel].count())
 
 
@@ -1200,7 +1198,7 @@ class TestGroupViews(TestCase):
         self.assertTemplateUsed(response, 'registration/login.html')
         
         # unauthorized
-        self.assert_(c.login(username=user0.username, password='secret'))
+        self.assertTrue(c.login(username=user0.username, password='secret'))
         response = c.get(url % args)
         self.assertEqual(403, response.status_code)
         response = c.post(url % args)
@@ -1273,8 +1271,7 @@ class TestGroupViews(TestCase):
 
         self.assertEqual(200, response.status_code)
         self.assertEquals('text/html; charset=utf-8', response['content-type'])
-        self.assertTemplateUsed(response, 'object_permissions/permissions/user_row.html')
-        self.assert_(user0.has_perm('admin', group))
+        self.assertTrue(user0.has_perm('admin', group))
         self.assertEqual(['admin'], get_user_perms(user0, group))
         
         # check signal fired with correct values
@@ -1305,7 +1302,7 @@ class TestGroupViews(TestCase):
         self.assertTemplateUsed(response, 'registration/login.html')
         
         # unauthorized user - wrong group
-        self.assert_(c.login(username=user0.username, password='secret'))
+        self.assertTrue(c.login(username=user0.username, password='secret'))
         response = c.get(url % group1.pk)
         self.assertEqual(403, response.status_code)
         
@@ -1314,7 +1311,7 @@ class TestGroupViews(TestCase):
         self.assertEqual(404, response.status_code)
         
         # authorized user - group member
-        self.assert_(c.login(username=user0.username, password='secret'))
+        self.assertTrue(c.login(username=user0.username, password='secret'))
         response = c.get(url % group.pk)
         self.assertEqual(200, response.status_code)
         self.assertTemplateUsed(response, 'object_permissions/permissions/objects.html')
