@@ -19,20 +19,19 @@ class ObjectPermissionForm(forms.Form):
     """
     Form used for editing permissions
     """
-    permissions = forms.MultipleChoiceField(required=False, \
+    permissions = forms.MultipleChoiceField(required=False,
                                             widget=forms.CheckboxSelectMultiple)
     user = forms.ModelChoiceField(queryset=User.objects.all(), required=False)
-    group = forms.ModelChoiceField(queryset=Group.objects.all(), \
+    group = forms.ModelChoiceField(queryset=Group.objects.all(),
                                    required=False)
-    
-    obj = forms.ModelChoiceField(queryset=None, required=True)
+    obj = forms.ModelChoiceField(queryset=None)
     
     # dictionary used for caching the choices for specific models
     choices = {}
     
     def __init__(self, model, *args, **kwargs):
         """
-        @param object - the object being granted permissions
+        @param model - the object being granted permissions
         """
         super(ObjectPermissionForm, self).__init__(*args, **kwargs)
         
@@ -141,7 +140,7 @@ class ObjectPermissionFormNewUsers(ObjectPermissionForm):
 
 
 def view_users(request, object_, url, \
-               template='object_permissions/permissions/users.html'):
+               template='object_permissions/permissions/users.html', rest=False):
     """
     Generic view for rendering a list of Users who have permissions on an
     object.
@@ -150,19 +149,26 @@ def view_users(request, object_, url, \
     be done in another view which calls this view for display
     
     @param request: HttpRequest
-    @param object: object to list Users and Groups for
+    @param object_: object to list Users and Groups for
     @param url: base url for editing permissions
     @param template: template for rendering User/Group list.
     """
     users = get_users(object_, groups=False)
     groups = get_groups(object_)
-    return render_to_response(template, \
+
+    if not rest:
+        return render_to_response(template, \
             {'object': object_,
              'users':users,
              'groups':groups,
-             'url':url}, \
+             'url':url},
         context_instance=RequestContext(request),
     )
+    else:
+        return {'object': object_,
+             'users':users,
+             'groups':groups,
+             'url':url}
 
 
 def view_permissions(request, obj, url, user_id=None, group_id=None,
@@ -175,7 +181,7 @@ def view_permissions(request, obj, url, user_id=None, group_id=None,
     configured with a model and url.  It may also be customized by adding custom
     templates or changing the pk field.
     
-    @param object: object permissions are being set on
+    @param obj: object permissions are being set on
     @param url: name of url being edited
     @param user_id: ID of User being edited
     @param group_id: ID of Group being edited
@@ -193,28 +199,28 @@ def view_permissions(request, obj, url, user_id=None, group_id=None,
             if form.update_perms():
                 # send correct signal based on new or edited user
                 if data['new']:
-                    view_add_user.send(sender=obj.__class__, \
-                                       editor=request.user, \
+                    view_add_user.send(sender=obj.__class__,
+                                       editor=request.user,
                                        user=edited_user, obj=obj)
                 else:
-                    view_edit_user.send(sender=obj.__class__, \
-                                        editor=request.user, \
+                    view_edit_user.send(sender=obj.__class__,
+                                        editor=request.user,
                                         user=edited_user, obj=obj)
                 
                 # return html to replace existing user row
                 if form_user:
-                    return render_to_response(user_template, \
+                    return render_to_response(user_template,
                                 {'object':obj, 'user_detail':form_user, 'url':url},
                                 context_instance=RequestContext(request))
                 else:
-                    return render_to_response(group_template, \
+                    return render_to_response(group_template,
                                 {'object':obj, 'group':group, 'url':url},
                                 context_instance=RequestContext(request))
                 
             else:
                 # no permissions, send ajax response to remove user
-                view_remove_user.send(sender=obj.__class__, \
-                                      editor=request.user, user=edited_user, \
+                view_remove_user.send(sender=obj.__class__,
+                                      editor=request.user, user=edited_user,
                                       obj=obj)
                 id = ('"user_%d"' if form_user else '"group_%d"')%edited_user.pk
                 return HttpResponse(id, mimetype='application/json')
@@ -225,26 +231,26 @@ def view_permissions(request, obj, url, user_id=None, group_id=None,
 
     if user_id:
         form_user = get_object_or_404(User, id=user_id)
-        data = {'permissions':get_user_perms(form_user, obj, False), \
+        data = {'permissions':get_user_perms(form_user, obj, False),
                 'user':user_id, 'obj':obj}
     elif group_id:
         group = get_object_or_404(Group, id=group_id)
-        data = {'permissions':get_group_perms(group, obj), \
+        data = {'permissions':get_group_perms(group, obj),
                 'group':group_id, 'obj':obj}
     else:
         data = {}
         
     form = ObjectPermissionFormNewUsers(obj.__class__, data)
     
-    return render_to_response('object_permissions/permissions/form.html', \
-                {'form':form, 'obj':obj, 'user_id':user_id, \
-                'group_id':group_id, 'url':url}, \
+    return render_to_response('object_permissions/permissions/form.html',
+                {'form':form, 'obj':obj, 'user_id':user_id,
+                'group_id':group_id, 'url':url},
                context_instance=RequestContext(request))
 
 
 @login_required
-def view_obj_permissions(request, class_name, obj_id=None, \
-    user_id=None, group_id=None, \
+def view_obj_permissions(request, class_name, obj_id=None,
+    user_id=None, group_id=None,
     row_template='object_permissions/permissions/object_row.html'):
     """
     Generic view for editing permissions on an object when the user is already.
@@ -272,21 +278,21 @@ def view_obj_permissions(request, class_name, obj_id=None, \
             if form.update_perms():
                 # send correct signal based on new or edited user
                 if data['new']:
-                    view_add_user.send(sender=cls, \
-                                       editor=request.user, \
+                    view_add_user.send(sender=cls,
+                                       editor=request.user,
                                        user=edited_user, obj=data['obj'])
                 else:
-                    view_edit_user.send(sender=cls, \
-                                        editor=request.user, \
+                    view_edit_user.send(sender=cls,
+                                        editor=request.user,
                                         user=edited_user, obj=data['obj'])
                 
                 # return html to replace existing user row
-                return render_to_response(row_template, \
+                return render_to_response(row_template,
                     {'class_name':class_name, 'obj':data['obj'], 'persona':edited_user})
             else:
                 # no permissions, send ajax response to remove object
-                view_remove_user.send(sender=cls, \
-                                      editor=request.user, user=edited_user, \
+                view_remove_user.send(sender=cls,
+                                      editor=request.user, user=edited_user,
                                       obj=data['obj'])
                 id = '"%s_%s"' % (class_name, obj_id)
                 return HttpResponse(id, mimetype='application/json')
@@ -296,7 +302,6 @@ def view_obj_permissions(request, class_name, obj_id=None, \
         return HttpResponse(content, mimetype='application/json')
     
     # GET - create form for editing and return as html
-    
     if obj_id:
         obj = get_object_or_404(cls, pk=obj_id)
         data = {'obj':obj}
@@ -304,37 +309,37 @@ def view_obj_permissions(request, class_name, obj_id=None, \
             form_user = get_object_or_404(User, id=user_id)
             data['user'] = user_id
             data['permissions'] = get_user_perms(form_user, obj, False)
-            url = reverse('user-edit-permissions', \
+            url = reverse('user-edit-permissions',
                           args=(user_id, class_name, obj_id))
         elif group_id:
             group = get_object_or_404(Group, id=group_id)
             data['group'] = group_id
             data['permissions'] = get_group_perms(group, obj)
-            url = reverse('group-edit-permissions', \
+            url = reverse('group-edit-permissions',
                           args=(group_id, class_name, obj_id))
     else:
         obj = None
         if user_id:
             get_object_or_404(User, id=user_id)
             data={'user':user_id}
-            url = reverse('user-add-permissions', \
+            url = reverse('user-add-permissions',
                           args=(user_id, class_name))
         elif group_id:
             get_object_or_404(Group, id=group_id)
             data={'group':group_id}
-            url = reverse('group-add-permissions', \
+            url = reverse('group-add-permissions',
                           args=(group_id, class_name))
     
     form = ObjectPermissionFormNewUsers(cls, data)
-    return render_to_response('object_permissions/permissions/form.html', \
+    return render_to_response('object_permissions/permissions/form.html',
             {'form':form, 'obj':obj, 'user_id':user_id, 'group_id':group_id, 
-             'url':url}, \
+             'url':url},
             context_instance=RequestContext(request))
     
     
 
 @login_required
-def all_permissions(request, id, \
+def all_permissions(request, id,
                     template="object_permissions/permissions/objects.html"):
     """
     Generic view for displaying permissions on all objects.
@@ -345,13 +350,11 @@ def all_permissions(request, id, \
     """
     user = request.user
     
-    if not (user.is_superuser or id==user.pk):
+    if not user.is_superuser:
         return HttpResponseForbidden('You do not have sufficient privileges')
     
-    if user.is_superuser:
-        user = get_object_or_404(User, pk=id)
-    
-    perm_dict = user.get_all_objects_any_perms(groups=False)
+    user_detail = get_object_or_404(User, pk=id)
+    perm_dict = user_detail.get_all_objects_any_perms(groups=False)
 
     # exclude group permissions from this view.  they are treated special
     try:
@@ -366,7 +369,7 @@ def all_permissions(request, id, \
     for cls, objs in perm_dict.items():
         repacked[cls.__name__] = objs
     
-    return render_to_response(template, \
-            {'persona':user, 'perm_dict':repacked}, \
+    return render_to_response(template,
+            {'persona':user_detail, 'perm_dict':repacked},
         context_instance=RequestContext(request),
     )
\ No newline at end of file
